@@ -9,7 +9,7 @@ import asyncio, re, os, subprocess, click, shutil, pprint, argparse
 from copy import deepcopy
 from alive_progress import alive_bar
 from fastmcp import Client
-from agentmake import agentmake, getOpenCommand, getDictionaryOutput, edit_configurations, writeTextFile, getCurrentDateTime, AGENTMAKE_USER_DIR, USER_OS, DEVELOPER_MODE, DEFAULT_AI_BACKEND
+from agentmake import agentmake, getOpenCommand, getDictionaryOutput, edit_configurations, readTextFile, writeTextFile, getCurrentDateTime, AGENTMAKE_USER_DIR, USER_OS, DEVELOPER_MODE, DEFAULT_AI_BACKEND
 from agentmake.utils.handle_text import set_log_file_max_lines
 from rich.console import Console
 from rich.markdown import Markdown
@@ -47,6 +47,7 @@ if os.path.isfile(user_bible) and os.path.getsize(user_bible) < 380000000:
 # AI backend
 parser = argparse.ArgumentParser(description = """BibleMate AI CLI options""")
 parser.add_argument("-b", "--backend", action="store", dest="backend", help="AI backend; overrides the default backend temporarily.")
+parser.add_argument("-mcp", "--mcp", action="store", dest="mcp", help=f"specify a custom MCP server to use, e.g. 'http://127.0.0.1:{config.mcp_port}/mcp/'")
 args = parser.parse_args()
 # write to the `config.py` file temporarily for the MCP server to pick it up
 if args.backend:
@@ -60,9 +61,19 @@ else:
 AGENTMAKE_CONFIG["backend"] = config.backend
 
 # The client that interacts with the Bible Study MCP server
-builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
-user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py") # The user path has the same basename as the built-in one; users may copy the built-in server settings to this location for customization. 
-client = Client(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
+if args.mcp:
+    client = Client(args.mcp)
+else:
+    builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
+    user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py") # The user path has the same basename as the built-in one; users may copy the built-in server settings to this location for customization. 
+    client = Client(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
+
+def mcp():
+    builtin_mcp_server = os.path.join(os.path.dirname(os.path.realpath(__file__)), "bible_study_mcp.py")
+    user_mcp_server = os.path.join(AGENTMAKE_USER_DIR, "biblemate", "bible_study_mcp.py")
+    mcp_script = readTextFile(user_mcp_server if os.path.isfile(user_mcp_server) else builtin_mcp_server)
+    mcp_script = mcp_script.replace("mcp.run(show_banner=False)", f'''mcp.run(show_banner=False, transport="http", port={config.mcp_port})''')
+    exec(mcp_script)
 
 def main():
     asyncio.run(main_async())
@@ -257,7 +268,8 @@ async def main_async():
                 ".tools": "list available tools",
                 ".plans": "list available plans",
                 #".resources": "list available resources", # TODO explore relevant usage for this project
-                ".promptengineering": "toggle auto prompt engineering",
+                ".promptengineer": "toggle auto prompt engineering",
+                ".lite": "toggle lite context",
                 ".steps": "configure the maximum number of steps",
                 ".matches": "configure the maximum number of semantic matches",
                 ".backup": "backup conversation",
@@ -293,9 +305,8 @@ async def main_async():
             elif user_request.startswith(".load") and re.search('''.py['" ]*?$''', user_request) and os.path.isfile(re.sub('''^['" ]*?([^'" ].+?)['" ]*?$''', r"\1", user_request[6:])):
                 try:
                     file_path = re.sub('''^['" ]*?([^'" ].+?)['" ]*?$''', r"\1", user_request[6:])
-                    backup_conversation(console, messages, master_plan) 
-                    with open(file_path, "r", encoding="utf-8") as f:
-                        messages = eval(f.read())
+                    backup_conversation(console, messages, master_plan)
+                    messages = eval(readTextFile(file_path))
                     user_request = ""
                     master_plan = ""
                     console.clear()
@@ -360,12 +371,18 @@ async def main_async():
                         write_user_config()
                         console.print("Maximum number of semantic matches set to", config.max_semantic_matches, justify="center")
                     console.rule()
-                elif user_request == ".promptengineering":
+                elif user_request == ".promptengineer":
                     config.prompt_engineering = not config.prompt_engineering
                     write_user_config()
                     console.rule()
                     console.print("Prompt Engineering Enabled" if config.prompt_engineering else "Prompt Engineering Disabled", justify="center")
                     console.rule()
+                elif user_request == ".lite":
+                    config.lite = not config.lite
+                    write_user_config()
+                    console.rule()
+                    console.print("Lite Context Enabled" if config.lite else "Lite Context Disabled", justify="center")
+                    console.rule()
                 elif user_request == ".mode":
                     default_ai_mode = "chat" if config.agent_mode is None else "agent" if config.agent_mode else "partner"
                     ai_mode = await dialogs.getValidOptions(
